SystemOrganization addCategory: #'RSS-Tests-Core'!

!WAPackage class methodsFor: '*rss-tests-core' stamp: 'lr 12/13/2008 13:11'!
rssTestsCore
	^ self new
		name: 'RSS-Tests-Core';
		description: 'Unit tests for the "RSS-Core" package.';
		addDependency: 'RSS-Core';
		yourself! !

TestCase subclass: #RRRenderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRRenderTest methodsFor: 'running' stamp: 'jf 1/22/2009 02:43'!
performTest
	| context |
	context := WARequestContext
		request: nil response: nil 
		codec: (WAPlatform current codecForEncoding: 'utf-8').
	WACurrentRequestContext 
		use: context
		during: [ super performTest ]! !

!RRRenderTest methodsFor: 'private' stamp: 'pmm 8/16/2007 22:50'!
render: aBlock
	^RRRssRenderCanvas builder render: aBlock! !

!RRRenderTest methodsFor: 'private' stamp: 'pmm 5/31/2008 18:47'!
renderFull: aBlock
	^self renderFull: aBlock rootBlock: nil! !

!RRRenderTest methodsFor: 'private' stamp: 'jf 1/23/2009 13:39'!
renderFull: aBlock rootBlock: anObject
	^RRRssRenderCanvas builder
		documentClass: WAXmlDocument;
		fullDocument: true;
		rootBlock: anObject;
		render: aBlock! !

!RRRenderTest methodsFor: 'testing' stamp: 'pmm 1/1/2009 18:50'!
testEmail
	| actual expected |
	actual := self render: [ :rss |
		rss author: (WAEmailAddress address: 'joesmith@example.com' username: 'Joe Smith') ].
	expected := '<author>Joe Smith &lt;joesmith@example.com&gt;</author>'.
	self assert: actual = expected! !

!RRRenderTest methodsFor: 'testing' stamp: 'pmm 3/1/2007 22:47'!
testExample
	| acutalContent expectedContent |
	acutalContent := self render: [ :rss |
		rss description: 'Das super geile Blog.'.
		rss contentEncoded: '<p>Das super geile Blog.</p>'.
		rss generator: 'Pier 1.0.9-alpha'.
		rss language english ].
	expectedContent := '<description>Das super geile Blog.</description><content:encoded><!![CDATA[<p>Das super geile Blog.</p>]]></content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language>'.
	self assert: acutalContent = expectedContent! !

!RRRenderTest methodsFor: 'testing' stamp: 'pmm 4/9/2007 19:43'!
testRenderExample
	| acutalContent expectedContent |
	acutalContent := self render: [ :rss |
		rss description: 'Das super geile Blog.'.
		rss renderContentEncoded: [ :html |
			html paragraph:  'Das super geile Blog.' ].
		rss generator: 'Pier 1.0.9-alpha'.
		rss language english ].
	expectedContent := '<description>Das super geile Blog.</description><content:encoded>&lt;p&gt;Das super geile Blog.&lt;/p&gt;</content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language>'.
	self assert: acutalContent = expectedContent! !

!RRRenderTest methodsFor: 'testing' stamp: 'pmm 5/31/2008 18:54'!
testRenderExampleFull
	| acutalContent expectedContent |
	acutalContent := self
		renderFull: [ :rss |
			rss description: 'Das super geile Blog.'.
			rss renderContentEncoded: [ :html |
				html paragraph:  'Das super geile Blog.' ].
			rss generator: 'Pier 1.0.9-alpha'.
			rss language english ]
		rootBlock: [ :root |
			root stylesheet beCss; url: 'http://yourserver.com/path/rss.css' ].
	
	expectedContent := '<?xml version="1.0" encoding="utf-8"?><?xml-stylesheet type="text/css" href="http://yourserver.com/path/rss.css"?><rss version="2.0" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:wfw="http://wellformedweb.org/CommentAPI/" xmlns:dc="http://purl.org/dc/elements/1.1/"><channel><description>Das super geile Blog.</description><content:encoded>&lt;p&gt;Das super geile Blog.&lt;/p&gt;</content:encoded><generator>Pier 1.0.9-alpha</generator><language>en</language></channel></rss>'.
	self assert: acutalContent = expectedContent! !

!RRRenderTest methodsFor: 'testing' stamp: 'pmm 9/5/2007 23:08'!
testWithLineBreaks
	| acutalContent expectedContent |
	acutalContent := self render: [ :rss |
		rss withLineBreaks: 'das
super
geile
Blog' ].
	expectedContent := 'das&lt;br/&gt;super&lt;br/&gt;geile&lt;br/&gt;Blog'.
	self assert: acutalContent = expectedContent! !

TestCase subclass: #RRRfc822DateTimeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RSS-Tests-Core'!

!RRRfc822DateTimeTest methodsFor: 'private' stamp: 'pmm 8/31/2008 19:17'!
render: anObject
	^WARenderCanvas builder
		render: [ :html | html render: anObject ]! !

!RRRfc822DateTimeTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 20:23'!
testNewDateAndTime
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 1 hour: 9 minute: 4 second: 4 offset: (Duration days: 0 hours: 2 minutes: 0 seconds: 0).
	emailDate := RRRfc822DateTime newDateAndTime: date.
	self assert: 'Fri, 01 Aug 2008 09:04:04 +0200' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'testing' stamp: 'jgf 2/3/2009 10:38'!
testNewDateAndTimeTimezoneString
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 31 hour: 19 minute: 14 second: 24 offset: Duration zero.
	emailDate := RRRfc822DateTime
		newDateAndTime: date
		offset: (Duration days: 0 hours: -2 minutes: 0 seconds: 0).
	self assert: 'Sun, 31 Aug 2008 19:14:24 -0200' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 19:31'!
testNewDateAndTimeUtc
	| date emailDate |
	date := DateAndTime year: 2008 month: 8 day: 31 hour: 19 minute: 14 second: 24 offset: (Duration days: 0 hours: 2 minutes: 0 seconds: 0).
	emailDate := RRRfc822DateTime newUtc: date.
	self assert: 'Sun, 31 Aug 2008 17:14:24 UT' = (self render: emailDate)! !

!RRRfc822DateTimeTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 19:29'!
testOffsetString
	| duration formatted |
	duration := Duration days: 0 hours: 2 minutes: 3 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '+0203' = formatted.
	
	duration := Duration days: 0 hours: -2 minutes: 0 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '-0200' = formatted.
	
	duration := Duration days: 0 hours: 0 minutes: -3 seconds: 0.
	formatted := RRRfc822DateTime offsetString: duration.
	self assert: '-0003' = formatted! !
